# Copyright 2015 VMware, Inc.  All rights reserved. -- VMware Confidential
#
''' Module containing reporting utilities.
'''
import logging
import types

from l10n import LocalizableMessage
logger = logging.getLogger(__name__)

class _ProgressReporter(object):
    def __init__(self, componentName):
        '''Reporter constructor

        @param componentName: Name of the component going to report progress
        @type componentName: str
        '''
        self.componentName = componentName

    def updateProgress(self, percentage, message=None):
        '''Updates the progress of the component.

        @param percentage: the progress percentage
        @type percentage: integer

        @param message: the progress status message
        @type message: l10n.LocalizableMessage
        '''
        # Validate the input
        if not isinstance(percentage, types.IntType):
            raise ValueError("Expected percentage to be integer property, got %s",
                             type(percentage))
        if message and not isinstance(message, LocalizableMessage):
            raise ValueError("Expected message to be LocalizableMessage, got %s",
                             type(message))

        # Log the input, until we start to persist it.
        if message:
            logger.info("Reported progres percentage=%s, message=%s",
                        percentage, message)
        else:
            logger.info("Reported progress percentage=%s", percentage)
        # TODO iradev: persit the data and carry it over to the CPO/framework


def getProgressReporter():
    # TODO iradev: automatically set component name
    componentName = None
    return _ProgressReporter(componentName)