#!/bin/bash
# This is a script which will be launched by the software-packages plugin
# after the RPM install transaction is complete
# The caller of this script expects the services to be started after its
# execution.

#PR 1735343: Remove pivotal-tc-server RPM as we no longer use it.
/usr/bin/rpm -q pivotal-tc-server-standard >/dev/null 2>&1
if [ "$?" -eq "0" ]; then
     rpm -e --nodeps pivotal-tc-server-standard >/dev/null 2>&1
fi

#PR 1940681: Enforce HTTPS for the Content Library service.
perl -pi -e 's/allow\s+allow/redirect allow/' /etc/vmware-rhttpproxy/endpoints.conf.d/cls.conf

# Update init scripts with service dependenices.
/bin/update-svc-deps
chgrp cis /usr/java/jre-vmware/bin
chmod 755 /usr/java/jre-vmware/bin
chgrp cis /usr/java/jre-vmware/bin/java
chmod 755 /usr/java/jre-vmware/bin/java

grep -q 'relativepath.*ntp.*rpm' \
/storage/core/software-packages/staged-configuration.json \
&& pgrep ntpd \
&& echo 'restarting ntpd' \
&& systemctl restart ntpd

# Get the deployment type or assume embedded as default
deploymentType=`/bin/install-parameter deployment.node.type embedded`
if [ $deploymentType == 'embedded' -o $deploymentType == 'management' ]
then
     ${VMWARE_PYTHON_BIN} /usr/lib/vmware-vpx/sps/scripts/sps_update.py
fi
true

DIR=$(dirname $0)
/opt/vmware/bin/python $DIR/configureDnsCaching.py

#PR 2337855: Remove/uninstall openJRE,apache-tomcat
#and apache-ant in existing deployed VC, as we are no longer using it.
rpmRemoveList=("apache-tomcat" "apache-ant" "openjre")
for rpm in "${rpmRemoveList[@]}"
do
    if [ ! -z `rpm -qa | grep $rpm` ];then
        rpm -qa | grep "$rpm" | xargs rpm -e --nodeps > /dev/null 2>&1
        if [ "$?" -ne "0" ];then
            echo "Error in uninstalling $rpm"
            break
        else
            echo "Uninstalled $rpm"
        fi
    fi
done

#PR 2347344: vmw python should point to photon python
if [ -e "/opt/vmware/bin/python" ]; then
    mv /opt/vmware/bin/python /opt/vmware/bin/python.bak
else
    mkdir -p /opt/vmware/bin
fi
# Point vmw python to photon python.
ln -sf /usr/bin/python /opt/vmware/bin/python

#PR 1820388, update sendmail.cf post patch
if [ $deploymentType == 'embedded' -o $deploymentType == 'management' ]
then
    /usr/lib/vmware-vpx/config_sendmail.sh
fi

#Exit the patching and remove the pycrypto packaged
function exitPatchingAndCleanup() {
    if [ -d /usr/lib/applmgmt/pycrypto ]
    then
        rm -rf /usr/lib/applmgmt/pycrypto
    fi
    exit 1
}

# Function to Downgrade pycrypto to stable version
function checkAndInstallStablePycrypto() {
    if rpm -qa | grep pycrypto-2.7a1-3.ph1.x86_64 > /dev/null 2>&1
    then
        echo "Found pycrypto-2.7a1-3.ph1.x86_64!"
        if ls /usr/lib/applmgmt/pycrypto/pycrypto* > /dev/null 2>&1
        then
	    echo "Found the stable pycrypto file!"
	    echo "Un-installing pycrypto-2.7a1-3.ph1.x86_64"
	    rpm -e pycrypto-2.7a1-3.ph1.x86_64 --nodeps > /dev/null 2>&1
	    if [ "$?" -ne "0" ]
	    then
	        echo "Error in Un-installing pycrypto!"
	        exitPatchingAndCleanup
	    else
	        echo "Installing stable pycrypto"
	        rpm -Uvh /usr/lib/applmgmt/pycrypto/pycrypto* --force > /dev/null 2>&1
	        if [ "$?" -ne "0" ]
	        then
		    echo "Error in Installing pycrypto!"
	            exitPatchingAndCleanup
	        else
		    echo "pycrypto RPM installed successfully!"
                fi
	    fi
        fi
    fi
    rm -rf /usr/lib/applmgmt/pycrypto
}

function changeDiagnosticsDirectory() {
    DIAGNOSTICS_PATH=/etc/vmware-vpx/docRoot/diagnostics
    if [ ! -e ${DIAGNOSTICS_PATH} ] || ([ ! -L ${DIAGNOSTICS_PATH} ] && [ -d ${DIAGNOSTICS_PATH} ]); then
        rm -rf ${DIAGNOSTICS_PATH}
        mkdir '/storage/log/diagnostics'
        ln -s '/storage/log/diagnostics/' ${DIAGNOSTICS_PATH}
    fi
}

# Check if unstable version of pycrypto is installed in VC
# if its found then downgrade it to the stable version.
checkAndInstallStablePycrypto

# PR 2527750, after patching, setting the default shell to appliancesh
# Changing the root and dnsmasq user using /bin/bash to /bin/appliancesh
function checkAndUpdateApplianceShell() {
    appliance_shell="/bin/appliancesh"
    default_shell="/usr/sbin/useradd -D | grep -i 'SHELL=' | cut -d'=' -f2"
    if [ $(eval "$default_shell") != "$appliance_shell" ];then
        /usr/sbin/useradd -D -s /bin/appliancesh
        chsh -s /bin/appliancesh root
        chsh -s /bin/appliancesh dnsmasq
    fi
}

checkAndUpdateApplianceShell

# Change diagnostics directory to avoid root exhaustion
DOC_ROOT_PATH=/etc/vmware-vpx/docRoot
if [ -d ${DOC_ROOT_PATH} ]; then
    changeDiagnosticsDirectory
fi

# PR 2591234 : patch syslog config according to new RPM changes.
# PR 2688539 : patch syslog to remove incorrect TLS padding.
echo "Patching syslog.conf"
python /usr/lib/applmgmt/syslog/py/vmware/appliance/syslog/syslog_patch.py
if [ "$?" -ne "0" ];then
    echo "Error in patching rsyslog.conf"
else
    echo "rsyslog.conf patched successfully"
fi
