#########################################################################
# Copyright 2017 VMware, Inc. All rights reserved. -- VMware Confidential
#########################################################################

'''
    This python script is used to filter version of the vCenter Server
    Appliance.
    This script reads the current version installed on the VCSA and the
    current patch's supported version. If the installed version VCSA is
    present in the supported version list of the patch, It allows patching
    else stops the patching process.
'''
import sys
import json
import os
import logging
from os.path import join, exists, abspath, dirname
from logging import handlers as loghandler

############# Setup logging ###############
# Debug logging to file
logger = logging.getLogger()
logger.setLevel(logging.DEBUG)
logger.handlers = []
fhandler = loghandler.WatchedFileHandler(
                        "/var/log/vmware/applmgmt/software-packages.log")
datefmt = "%Y-%m-%dT%H:%M:%S.%j"
fformatter = logging.Formatter(fmt="%(asctime)s [%(process)d]%(levelname)s:%(name)s:%(message)s",
                               datefmt=datefmt)
fhandler.setFormatter(fformatter)
fhandler.setLevel(logging.DEBUG)
logger.addHandler(fhandler)

# logging to console
chandler = logging.StreamHandler(sys.stdout)
cformatter = logging.Formatter(fmt=" [%(asctime)s] : %(message)s",
                               datefmt=datefmt)
chandler.setFormatter(cformatter)
chandler.setLevel(logging.INFO)
logger.addHandler(chandler)

############# Setup logging ###############

curfilePath = abspath(join(dirname(__file__), os.pardir))
PATCH_HEADER_CONF = os.path.join( curfilePath, 'headers', 'va_patchheader.json')
sys.path.append('/usr/lib/applmgmt/base/py/')
from vmware.vherd.base import update_utils



def filter():
    with open(update_utils.UPDATE_CONF, "r") as updateConf:
        updateConfJson = json.load(updateConf)
    curVersion = updateConfJson['version']
    #Manipulation on hotpatch
    curVersion = curVersion[:-2] + "00"

    with open(PATCH_HEADER_CONF, "r") as pJson:
        patchHeaderJson = json.load(pJson)
    versionSupported = patchHeaderJson['version_supported']

    if curVersion in versionSupported or curVersion == patchHeaderJson['version']:
        logger.info("Compatible patch")
        return 0
    else:
        logger.error("Unsuported version of patch selected.")
        return 1


