"""Content Library Patch Logic for 6.5 minor releases

"""
import logging
import os
import shutil

from patches.constants import PATCH_VERSION_6_5_1
from patches.messages import PATCH_SUMMARY_6_5_1
from base import patch_info, patch_test


__author__ = 'VMware, Inc.'
__copyright__ = 'Copyright 2016-2017 VMware, Inc. All rights reserved.'


logger = logging.getLogger(__name__)

# Pivotal tc Server runtime instance directory on Linux
TC_SERVER_DIR = '/usr/lib/vmware-content-library/server'

# Tanuki wrapper directory on Linux
WRAPPER_DIR = '/usr/lib/vmware-content-library/wrapper'

@patch_info(PATCH_VERSION_6_5_1, PATCH_SUMMARY_6_5_1)
def patch_executor_6_5_1(patch_context):
    cleanup_dir(TC_SERVER_DIR)
    cleanup_dir(WRAPPER_DIR)


@patch_test(PATCH_VERSION_6_5_1)
def patch_tester_6_5_1(patch_context):
    is_success = not os.path.exists(TC_SERVER_DIR)
    logger.info("Successfully uninstalled tc Server: %s", is_success)

    is_success = not os.path.exists(WRAPPER_DIR)
    logger.info("Successfully uninstalled Tanuki wrapper: %s", is_success)


def cleanup_dir(dir):
    logger.info("Removing: %s", dir)
    if os.path.exists(dir):
        shutil.rmtree(dir, True)
        logger.info("Removed: %s", dir)
