import sys
import os
import json
import platform
import logging

from patch_specs import DiscoveryResult, ValidationResult, Question, Mismatch, Requirements, PatchInfo,\
    RequirementsResult

from extensions import extend, Hook
from l10n import msgMetadata as _T, localizedString as _
import vcsa_utils
from reporting import getProgressReporter

from vcdb_db_utils import ( get_db_user_linux, get_db_pass_symkey, patch_db)



logger = logging.getLogger(__name__)

@extend(Hook.Discovery)
def discover(ctx):
    '''DiscoveryResult discover(PatchContext ctx) throw UserError'''
    return vcsa_utils.getComponentDiscoveryResult("dbconfig", displayName=_(_T("VCDB.displayName", "VMware vCenter Server Database")))

def _doVCDBPatching(ctx):
   logger.info("Retrieving DB user...")
   vcUser = get_db_user_linux()
   logger.info("DB user retrieved: %s", vcUser)

   logger.info("Retrieving DB password...")
   vcPass = get_db_pass_symkey()
   logger.info("DB password retrieved: ****")

   sourceVcVersion = "600"
   logger.info("Source version: %s", sourceVcVersion)

   logger.info("Execute DB patch...")
   patch_db(vcUser,vcPass,sourceVcVersion)
   logger.info("DB is patched.")




@extend(Hook.Patch)
def patch(ctx):
    '''void patch(PatchContext ctx) throw UserError'''
    progressReporter = getProgressReporter()
    progressReporter.updateProgress(0, _(_T("vcdb.patch.begin",
                                            'Start VCDB  patching')))
    _doVCDBPatching(ctx)
    progressReporter.updateProgress(100, _(_T("vcdb.patch.complete", 'patching VCDB completed')))