CREATE OR REPLACE FUNCTION rule_topn1_proc()
 RETURNS VOID
 
 
 
 
 
 
 
 
 
 AS $procedure$
     
    DECLARE
    v_start       timestamp with time zone;
    v_cnt_1       int;
    v_cnt_2       int;
    v_level       char(3);
    v_err         char(1) := 'N';
    v_errmsg      vpx_proc_log.description%type;
 
    v_status      vpx_job_log.status%type;
    v_recovery_period  smallint;
    v_last_run    vpx_job_log.last_run%type;
    v_last_stat   vpx_sample_time1.sample_time%type;
    v_job_id      int;
    v_log_rtn     int;
    v_time_level       smallint;
 BEGIN
    v_job_id             := 1;
    v_time_level         := 1;
    v_recovery_period    := 30;
 
    
    select status into v_status
    from vpx_job_log
    where job_id = v_job_id;
 
    
    if v_status = 'RUNNING' then
       RETURN;
    end if;
 
 
     
    SELECT SAMPLE_TIME into v_last_run
      FROM VPX_TOPN_STATE
     WHERE TIME_LEVEL = v_time_level;
 
 
    
    BEGIN
       select max(sample_time) - (v_recovery_period || ' min')::interval into v_last_stat
       from vpx_sample_time1;
    EXCEPTION
       when no_data_found then
          return;
    END;
 
     
     
     
     
     
     
 
    select SUBSTR(value,1,3) into v_level
    from vpx_parameter
    where name = 'DBProc.Log.Level.Topn.Calc1';
 
    
    v_level := COALESCE(v_level,'ERR');
 
     
    if v_level in('INF','CHK') then
       select count(1) into v_cnt_1
        from VPX_TOPN_PAST_DAY;
    end if;
 
    
    v_start := TIMEZONE('UTC',now());
 
    
    v_last_run := coalesce(v_last_run,v_last_stat -(v_recovery_period || ' min')::interval);
 
 
     
    IF v_last_run <= v_last_stat - (v_recovery_period || ' min')::interval then
       v_last_run := v_last_stat - (v_recovery_period || ' min')::interval;
    END IF;
 
   
    UPDATE vpx_job_log
    SET status = 'RUNNING'
    WHERE job_id = v_job_id;
 
    BEGIN
       PERFORM calc_topn1_proc(v_last_run,v_last_stat);
       EXCEPTION
       WHEN OTHERS THEN
          v_errmsg := 'Error:' || cast(sqlstate as VARCHAR(30)) || ' :' || coalesce(SQLERRM, '');
          v_err := 'Y';
    END;
 
    
    UPDATE vpx_job_log
    SET status = 'WAITING',last_run = COALESCE(v_last_stat,v_last_run)
    WHERE job_id = v_job_id;
 
     
    if v_level in('INF','CHK') then
      insert into vpx_proc_log(proc_name,
                  start_dt,
                  end_dt,
                  err_flag,
                  chk_flag,
                  description)
              values('CALC_TOPN1_PROC',
                  v_start,
                  TIMEZONE('UTC',now()),
                  v_err,
                  case v_level
                    when 'CHK' then 'Y'
                    else 'N'
                  end,
                  case v_err
                    when 'N' then v_level
                    else v_errmsg
                  end);
    end if;
 
     
     
    if v_level in('INF','CHK') then
       select count(1) INTO v_cnt_2
         from VPX_TOPN_PAST_DAY ;
 
       update vpx_proc_log
       set tgt_rows = COALESCE(v_cnt_2 -v_cnt_1,0)
       where proc_name = 'CALC_TOPN1_PROC'
       and start_dt = v_start;
    end if;
 
    v_err := 'N';
    
     
 
    select SUBSTR(value,1,3) INTO v_level
    from vpx_parameter
    WHERE name = 'DBProc.Log.Level.Topn.Purge1';
 
    
    v_level := coalesce(v_level,'ERR');
 
    
    if v_level in('INF','CHK') then
       select count(1) INTO v_cnt_1
         from VPX_TOPN_PAST_DAY;
    end if;
 
    
    v_start := TIMEZONE('UTC',now());
 
    BEGIN
       PERFORM clear_topn1_proc();
       EXCEPTION
       WHEN OTHERS THEN
          v_errmsg := 'Error:' || cast(sqlstate as VARCHAR(30)) || ' :' || coalesce(SQLERRM, '');
          v_err := 'Y';
    END;
 
     
    IF v_level in('INF','CHK') then
      insert into vpx_proc_log(proc_name,
                  start_dt,
                  end_dt,
                  err_flag,
                  chk_flag,
                  description)
           values('CLEAR_TOPN1_PROC',
                  v_start,
                  TIMEZONE('UTC',now()),
                  v_err,
                  case v_level
                    when 'CHK' then 'Y'
                    else 'N'
                  end,
                  case v_err
                    when 'N' then v_level
                    else v_errmsg
                  end);
    END IF;
 
     
     
    IF v_level in ('INF','CHK') then
       select count(1) INTO v_cnt_2
         from VPX_TOPN_PAST_DAY;
 
       update vpx_proc_log
       set src_rows = coalesce(v_cnt_1 -v_cnt_2,0)
       where proc_name = 'CLEAR_TOPN1_PROC'
       and start_dt = v_start;
    end if;
 
    
    select CAST(VALUE AS INTEGER) INTO v_log_rtn
      FROM vpx_parameter
     WHERE NAME = 'DBProc.Log.Buffer';
 
    DELETE FROM vpx_proc_log
    WHERE start_dt not in (SELECT start_dt
                            FROM vpx_proc_log
                           ORDER BY start_dt desc
                           LIMIT v_log_rtn);
 
    
 EXCEPTION
    WHEN OTHERS THEN
 
       UPDATE vpx_job_log
       SET status = 'WAITING'
       WHERE job_id = v_job_id;
       
 END; $procedure$
 LANGUAGE plpgsql;